@@ -29,11 +29,17 @@ VImageWidget::VImageWidget(QWidget *parent)
     mAuthor = new QLabel(this);
     mImage = new QLabel(this);
 
+    mAuthor->setStyleSheet("color: black; background-color: white");
+    mAuthor->setAlignment(Qt::AlignBottom | Qt::AlignRight);
+    mImage->setAlignment(Qt::AlignCenter);
+
     vbox->addWidget(mImage);
     vbox->addWidget(mAuthor);
 
     grabGesture(Qt::SwipeGesture);
 
+    setStyleSheet("background-color: white");
+
     setWindowFlags(windowFlags() | Qt::Window);
     setAttribute(Qt::WA_Maemo5StackedWindow);
 }
